@@ -23,9 +23,9 @@
  *
  * Contributor(s): ______________________________________.
  *
- * $Revision: 25392 $
+ * $Revision: 26959 $
  * $Author: rjongbloed $
- * $Date: 2011-03-22 23:29:41 -0500 (Tue, 22 Mar 2011) $
+ * $Date: 2012-02-08 17:56:28 -0600 (Wed, 08 Feb 2012) $
  */
 
 #ifdef __GNUC__
@@ -517,10 +517,32 @@ PMIMEInfo::PMIMEInfo(PInternetProtocol & socket)
 }
 
 
+PMIMEInfo::PMIMEInfo(const PStringToString & dict)
+  : PStringOptions(dict)
+{
+}
+
+
+PMIMEInfo::PMIMEInfo(const PString & str)
+{
+  PStringStream strm(str);
+  ReadFrom(strm);
+}
+
+
+PString PMIMEInfo::AsString() const
+{
+  PStringStream strm;
+  PrintOn(strm);
+  return strm;
+}
+
+
 void PMIMEInfo::PrintOn(ostream &strm) const
 {
+  bool crlf = strm.fill() == '\r';
   PrintContents(strm);
-  if (strm.fill() == '\r')
+  if (crlf)
     strm << '\r';
   strm << '\n';
 }
@@ -558,7 +580,7 @@ void PMIMEInfo::ReadFrom(istream &strm)
 
   PString line;
   PString lastLine;
-  while (!strm.bad() && !strm.eof()) {
+  while (strm.good()) {
     strm >> line;
     if (line.IsEmpty())
       break;
@@ -604,7 +626,7 @@ bool PMIMEInfo::AddMIME(const PString & line)
 }
 
 
-bool PMIMEInfo::AddMIME(const PString & fieldName, const PString & fieldValue)
+bool PMIMEInfo::InternalAddMIME(const PString & fieldName, const PString & fieldValue)
 {
   PString * str = GetAt(fieldName);
   if (str == NULL)
@@ -786,7 +808,7 @@ void PMIMEInfo::SetAssociation(const PStringToString & allTypes, PBoolean merge)
 PString PMIMEInfo::GetContentType(const PString & fType)
 {
   if (fType.IsEmpty())
-    return "text/plain";
+    return PMIMEInfo::TextPlain();
 
   PStringToString & types = GetContentTypes();
   if (types.Contains(fType))
@@ -802,6 +824,8 @@ const PCaselessString & PMIMEInfo::ContentTransferEncodingTag() { static const P
 const PCaselessString & PMIMEInfo::ContentDescriptionTag()      { static const PConstCaselessString s("Content-Description");       return s; }
 const PCaselessString & PMIMEInfo::ContentIdTag()               { static const PConstCaselessString s("Content-ID");                return s; }
 
+const PCaselessString & PMIMEInfo::TextPlain()                  { static const PConstCaselessString s("text/plain");                return s; }
+
 
 //////////////////////////////////////////////////////////////////////////////
 
