@@ -26,9 +26,9 @@
  *
  * Contributor(s): ______________________________________.
  *
- * $Revision: 20385 $
+ * $Revision: 26448 $
  * $Author: rjongbloed $
- * $Date: 2008-06-04 05:40:38 -0500 (Wed, 04 Jun 2008) $
+ * $Date: 2011-09-19 22:01:53 -0500 (Mon, 19 Sep 2011) $
  */
 
 #include <ptlib.h>
@@ -281,7 +281,8 @@ RegistryKey::RegistryKey(const PString & subkeyname, OpenMode mode)
     error = RegCreateKeyEx(basekey, subkey, 0, empty, REG_OPTION_NON_VOLATILE, KEY_ALL_ACCESS, NULL, &key, &disposition);
     if (error != ERROR_SUCCESS) {
       PTRACE(1, "PTLib\tCould not create registry entry "
-             << (basekey != NULL ? "" : LocalMachineStr) << subkey);
+             << (basekey == HKEY_LOCAL_MACHINE ? LocalMachineStr :
+                (basekey == HKEY_CURRENT_USER ? CurrentUserStr : "")) << subkey);
       key = NULL;
     }
   }
